summaryrefslogtreecommitdiffstats
path: root/src/import/chips/p9/procedures/hwp/pm/p9_pm_ocb_indir_access.H
diff options
context:
space:
mode:
authorSangeetha T S <sangeet2@in.ibm.com>2015-09-28 04:48:06 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2016-06-10 22:15:40 -0400
commit5e59404906922e1c5f3267b0ece5ea17de1a9c8e (patch)
treee715ccc0f6173519d076097bb8daf7aee827c394 /src/import/chips/p9/procedures/hwp/pm/p9_pm_ocb_indir_access.H
parent6b407bddd4a8c6bfa833ba0624dd21c30bc6dd12 (diff)
downloadtalos-hostboot-5e59404906922e1c5f3267b0ece5ea17de1a9c8e.tar.gz
talos-hostboot-5e59404906922e1c5f3267b0ece5ea17de1a9c8e.zip
JET: Level 2, Make p9_pm_ocb_indir_access FAPI 2.0 compliant
Change-Id: I63db5f7adb0714bd72b3fba9c253b00ba1dda03c Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/20874 Tested-by: Jenkins Server Reviewed-by: Gregory S. Still <stillgs@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/25668 Tested-by: FSP CI Jenkins Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/import/chips/p9/procedures/hwp/pm/p9_pm_ocb_indir_access.H')
-rw-r--r--src/import/chips/p9/procedures/hwp/pm/p9_pm_ocb_indir_access.H90
1 files changed, 46 insertions, 44 deletions
diff --git a/src/import/chips/p9/procedures/hwp/pm/p9_pm_ocb_indir_access.H b/src/import/chips/p9/procedures/hwp/pm/p9_pm_ocb_indir_access.H
index 130d383d8..8df54a999 100644
--- a/src/import/chips/p9/procedures/hwp/pm/p9_pm_ocb_indir_access.H
+++ b/src/import/chips/p9/procedures/hwp/pm/p9_pm_ocb_indir_access.H
@@ -7,7 +7,7 @@
/* */
/* EKB Project */
/* */
-/* COPYRIGHT 2015 */
+/* COPYRIGHT 2015,2016 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -16,49 +16,51 @@
/* deposited with the U.S. Copyright Office. */
/* */
/* IBM_PROLOG_END_TAG */
-// @file p9_pm_ocb_indir_access.H
-// @brief Access procedure to the OCC OCB indirect channels
+///
+/// @file p9_pm_ocb_indir_access.H
+/// @brief Access procedure to the OCC OCB indirect channels
+///
-// *HWP HWP Owner : Greg Still <stillgs@us.ibm.com>
-// *HWP Backup HWP Owner:
-// *HWP FW Owner : Bilicon Patil <bilpatil@in.ibm.com>
+// *HWP HWP Owner : Amit Kumar <akumar3@us.ibm.com>
+// *HWP HWP Backup Owner: Greg Still <stillgs@us.ibm.com>
+// *HWP FW Owner : Sangeetha T S <sangeet2@in.ibm.com>
// *HWP Team : PM
-// *HWP Level : 1
-// *HWP Consumed by : HS
+// *HWP Level : 2
+// *HWP Consumed by : FSP:HS
-#ifndef _P9_PM_OCBINDIRACC_H_
-#define _P9_PM_OCBINDIRACC_H_
+#ifndef _P9_PM_OCB_INDIR_ACCESS_H_
+#define _P9_PM_OCB_INDIR_ACCESS_H_
//------------------------------------------------------------------------------
// Includes
//------------------------------------------------------------------------------
+
#include <fapi2.H>
+#include <p9_pm.H>
#include <p9_pm_ocb_init.H>
//------------------------------------------------------------------------------
// Constant definitions
//------------------------------------------------------------------------------
-
namespace p9ocb
{
-enum P9_OCB_ACCESS_OP
+enum PM_OCB_ACCESS_OP
{
OCB_GET = 0x1,
OCB_PUT = 0x2
};
}
-
// function pointer typedef definition for HWP call support
typedef fapi2::ReturnCode (*p9_pm_ocb_indir_access_FP_t)
-(const fapi2::Target<fapi2::TARGET_TYPE_PROC_CHIP>& i_target,
- p9ocb::PM_OCB_CHAN_NUM i_ocb_chan,
- p9ocb::P9_OCB_ACCESS_OP i_ocb_op,
- const uint32_t i_ocb_req_length,
- fapi2::buffer<uint64_t>& io_ocb_buffer,
- uint32_t& o_ocb_act_length,
- const bool i_oci_address_valid,
- const uint32_t i_oci_address);
+(const fapi2::Target<fapi2::TARGET_TYPE_PROC_CHIP>&,
+ const p9ocb::PM_OCB_CHAN_NUM,
+ const p9ocb::PM_OCB_ACCESS_OP,
+ const uint32_t,
+ const bool,
+ const uint32_t,
+ uint32_t&,
+ fapi2::variable_buffer&);
//------------------------------------------------------------------------------
// Function prototype
@@ -71,33 +73,33 @@ extern "C"
/// been configured previously via p9_pm_ocb_indir_setup_[linear/circular]
/// procedures
///
/// @param[in] &i_target Chip target
/// @param[in] i_ocb_chan OCB channel number (0, 1, 2, 3)
/// @param[in] i_ocb_op Operation (Get, Put)
/// @param[in] i_ocb_req_length Requested length in the number of 8B
/// elements to be accessed (unit origin)
/// Number of bytes = (i_ocb_req_length) *
/// 8B
/// @param[in/out] &io_ocb_buffer Reference to fappi2::buffer
/// @param[out] &o_ocb_act_length Address containing to contain the actual
/// length in the number of 8B elements to
/// be accessed (zero origin)
/// Number of bytes = (i_ocb_act_length+1) *
/// 8B
/// @param[in] i_oci_address_valid Indicator that oci_address is to be used
/// @param[in] i_oci_address OCI Address to be used for the operation
/// @return FAPI2_RC_SUCCESS on success, else error.
fapi2::ReturnCode p9_pm_ocb_indir_access(
const fapi2::Target<fapi2::TARGET_TYPE_PROC_CHIP>& i_target,
- p9ocb::PM_OCB_CHAN_NUM i_ocb_chan,
- p9ocb::P9_OCB_ACCESS_OP i_ocb_op,
- const uint32_t i_ocb_req_length,
- fapi2::buffer<uint64_t>& io_ocb_buffer,
- uint32_t& o_ocb_act_length,
- const bool i_oci_address_valid,
- const uint32_t i_oci_address);
+ const p9ocb::PM_OCB_CHAN_NUM i_ocb_chan,
+ const p9ocb::PM_OCB_ACCESS_OP i_ocb_op,
+ const uint32_t i_ocb_req_length,
+ const bool i_oci_address_valid,
+ const uint32_t i_oci_address,
+ uint32_t& o_ocb_act_length,
+ fapi2::variable_buffer& io_ocb_buffer);
} // extern "C"
-#endif // _P9_PM_OCBINDIRACC_H_
+#endif // _P9_PM_OCB_INDIR_ACCESS_H_
OpenPOWER on IntegriCloud
@@ -71,33 +73,33 @@ extern "C"
/// procedures
///
-/// @param[in] &i_target Chip target
-/// @param[in] i_ocb_chan OCB channel number (0, 1, 2, 3)
-/// @param[in] i_ocb_op Operation (Get, Put)
-/// @param[in] i_ocb_req_length Requested length in the number of 8B
-/// elements to be accessed (unit origin)
-/// Number of bytes = (i_ocb_req_length) *
-/// 8B
-/// @param[in/out] &io_ocb_buffer Reference to fappi2::buffer
-/// @param[out] &o_ocb_act_length Address containing to contain the actual
-/// length in the number of 8B elements to
-/// be accessed (zero origin)
-/// Number of bytes = (i_ocb_act_length+1) *
-/// 8B
-/// @param[in] i_oci_address_valid Indicator that oci_address is to be used
-/// @param[in] i_oci_address OCI Address to be used for the operation
+/// @param[in] &i_target Chip target
+/// @param[in] i_ocb_chan OCB channel number (0, 1, 2, 3)
+/// @param[in] i_ocb_op Operation (Get, Put)
+/// @param[in] i_ocb_req_length Requested length in the number of 8B
+/// elements to be accessed (unit origin)
+/// Number of bytes = (i_ocb_req_length) *
+/// 8B
+/// @param[in] i_oci_address_valid Indicator that oci_address is to be used
+/// @param[in] i_oci_address OCI Address to be used for the operation
+/// @param[out] &o_ocb_act_length Address containing the actual length
+/// in the number of 8B elements to be
+/// accessed (zero origin)
+/// Number of bytes = (o_ocb_act_length+1) *
+/// 8B
+/// @param[in/out] &io_ocb_buffer Reference to fapi2::variable_buffer
/// @return FAPI2_RC_SUCCESS on success, else error.
fapi2::ReturnCode p9_pm_ocb_indir_access(